@@ -4,7 +4,7 @@ import yaml
 from termcolor2 import colored
 from dwhutils.TableReader import read_raw_sql_hub as r_hub
 from dwhutils.TableReader import read_raw_sql_sat as r_sat
-from db_connection import connect_to_db
+from dwhutils.db_connection import connect_to_db
 
 
 class ReadEntity:
