@@ -3,7 +3,7 @@ from datetime import datetime
 import pandas as pd
 from sqlalchemy import MetaData
 
-from Logger import logger
+from dwhutils.Logger import logger
 
 
 def read_raw_sql_hub(db_con, t_name: str, date: str, schema: str):
