@@ -1,14 +1,7 @@
 import pandas as pd
 from sqlalchemy import MetaData
 
-try:
-
-    from utils.db_connection import connect_to_db
-
-except ImportError:
-
-    from project.dags.utils.db_connection import connect_to_db
-
+from dwhutils.db_connection import connect_to_db
 
 class dynamic_lkp:
     def __init__(self):
